package com.guna.ocrlibrary.camera;

import android.content.Context;
import android.graphics.Canvas;
import android.util.AttributeSet;
import android.view.View;
import com.guna.ocrlibrary.camera.GraphicOverlay.Graphic;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

public class GraphicOverlay<T extends Graphic> extends View {
    
    public int mFacing = 0;
    private Set<T> mGraphics = new HashSet();
    
    public float mHeightScaleFactor = 1.0f;
    private final Object mLock = new Object();
    private int mPreviewHeight;
    private int mPreviewWidth;
    
    public float mWidthScaleFactor = 1.0f;

    public Set<T> getGraphic() {
        return this.mGraphics;
    }

    public static abstract class Graphic {
        private GraphicOverlay mOverlay;

        public abstract boolean contains(float f, float f2);

        public abstract void draw(Canvas canvas);

        public Graphic(GraphicOverlay overlay) {
            this.mOverlay = overlay;
        }

        public float scaleX(float horizontal) {
            return this.mOverlay.mWidthScaleFactor * horizontal;
        }

        public float scaleY(float vertical) {
            return this.mOverlay.mHeightScaleFactor * vertical;
        }

        public float translateX(float x) {
            if (this.mOverlay.mFacing == 1) {
                return ((float) this.mOverlay.getWidth()) - scaleX(x);
            }
            return scaleX(x);
        }

        public float translateY(float y) {
            return scaleY(y);
        }

        public void postInvalidate() {
            this.mOverlay.postInvalidate();
        }
    }

    public GraphicOverlay(Context context, AttributeSet attrs) {
        super(context, attrs);
    }

    public void clear() {
        synchronized (this.mLock) {
            this.mGraphics.clear();
        }
        postInvalidate();
    }

    public void add(T graphic) {
        synchronized (this.mLock) {
            this.mGraphics.add(graphic);
        }
        postInvalidate();
    }

    public void remove(T graphic) {
        synchronized (this.mLock) {
            this.mGraphics.remove(graphic);
        }
        postInvalidate();
    }

    public T getGraphicAtLocation(float rawX, float rawY) {
        T graphic;
        synchronized (this.mLock) {
            int[] location = new int[2];
            getLocationOnScreen(location);
            Iterator<T> it = this.mGraphics.iterator();
            while (true) {
                if (!it.hasNext()) {
                    graphic = null;
                    break;
                }
                graphic = (T) it.next();
                if (graphic.contains(rawX - ((float) location[0]), rawY - ((float) location[1]))) {
                    break;
                }
            }
        }
        return graphic;
    }

    public void setCameraInfo(int previewWidth, int previewHeight, int facing) {
        synchronized (this.mLock) {
            this.mPreviewWidth = previewWidth;
            this.mPreviewHeight = previewHeight;
            this.mFacing = facing;
        }
        postInvalidate();
    }

    /* access modifiers changed from: protected */
    public void onDraw(Canvas canvas) {
        super.onDraw(canvas);
        synchronized (this.mLock) {
            if (!(this.mPreviewWidth == 0 || this.mPreviewHeight == 0)) {
                this.mWidthScaleFactor = ((float) canvas.getWidth()) / ((float) this.mPreviewWidth);
                this.mHeightScaleFactor = ((float) canvas.getHeight()) / ((float) this.mPreviewHeight);
            }
            for (T graphic : this.mGraphics) {
                graphic.draw(canvas);
            }
        }
    }
}
